/**
 * This file contains all the callbacks triggered by the notificationListener.
 */

function connectingCallback(resultsList, detail) {
  resultsList.getHTMLElements(['#analysis-init-modal']);
  resultsList.analysisInitModal = M.Modal.init(resultsList.analysisInitModal,
                                               {dismissible: false});
  resultsList.analysisInitModal.open();
}

function connectedCallback(resultsList, detail) {
  resultsList.analysisInitModal.close();
}

function connectingFaildeCallback(resultsList, detail) {
  resultsList.getHTMLElements([
    '#analysis-init-progress',
    '#analysis-init-error'
  ]);
  resultsList.analysisInitProgress.classList.toggle('hide');
  resultsList.analysisInitError.classList.toggle('hide');
  resultsList.analysisInitError.textContent = detail.msg;
}

function queryDataPreparingCallback(resultsList, detail) {
  // remove all items from resultsList, like from the query issued before
  resultsList.clear()
  // get needed HTML Elements
  let results = detail.results;
  resultsList.getHTMLElements(
    ['#interactions-menu',
     '#recieved-match-count',
     '#total-match-count',
     '#text-lookup-count',
     '#text-lookup-titles',
     '#query-results-user-feedback',
     '#query-progress-bar',
     '#query-results-create',
     '#add-to-sub-results'
   ]);
  // set some initial values for the user feedback
  resultsList.recievedMatchCount.textContent = 0;
  resultsList.totalMatchCount.textContent = results.data.match_count;
  resultsList.textLookupTitles.textContent = '';
  resultsList.textLookupCount.textContent = 0;
  // show or enable some things for the user
  resultsList.interactionsMenu.classList.toggle('hide', false)
  resultsList.addToSubResults.setAttribute("disabled", "");
  resultsList.queryResultsUserFeedback.classList.toggle('hide', false);
  resultsList.queryProgressBar.classList.toggle('hide', false);
  // hide ore disable some things for the user
  resultsList.queryResultsCreate.classList.toggle('disabled', true);
}

function queryDataRecievingCallback(resultsList, detail) {
  // load the data into the resultsList and show them to the user
  let results = detail.results;
  let client = detail.client;
  let start = detail.dataLength;
  let resultItems = [];
  for (let [index, match] of Object.entries(results.data.matches).slice(start)) {
    resultItems.push({ ...match, ...{ 'index': parseInt(index) } });
  }
  if (client.dynamicMode) {
    resultsList.add(resultItems, (items) => {
      for (let item of items) {
        item.elm = resultsList.createResultRowElement(item, results.data);
      }
    });
  // update user feedback about query status
  resultsList.recievedMatchCount.textContent = results.data.matches.length;
  resultsList.queryProgressBar.firstElementChild.style.width = `${client.requestQueryProgress}%`;
  resultsList.textLookupCount.textContent = `${Object.keys(results.data.text_lookup).length}`;
  let titles = new Array();
  for (let [key, value] of Object.entries(results.data.text_lookup)) {
    titles.push(`${value.title} (${value.publishing_year})`);
  }
  resultsList.textLookupTitles.textContent = `${titles.join(', ')}`;
  // updating table on finished item creation callback via createResultRowElement
  resultsList.update();
  resultsList.changeHitsPerPage();
  resultsList.changeContext();
  } else if (!client.dynamicMode) {
    results.jsList.add(resultItems, (items) => {
      for (let item of items) {
        item.elm = results.jsList.createResultRowElement(item, payload.chunk,
                                                         true);
      }
    });
  }
}

function queryDataRecievedCallback(resultsList, detail) {
  // hide or disable some things for the user
  resultsList.queryResultsUserFeedback.classList.toggle('hide');
  resultsList.queryProgressBar.classList.toggle('hide');
  // show or enable some things for the user
  resultsList.queryResultsCreate.classList.toggle('disabled');
  resultsList.addToSubResults.removeAttribute("disabled");
}

function resultsDataRecievingCallback(resultsList, detail) {
  // hide or disable elments taht would trigger another cqp data request
}

function resultsDataRecievedCallback(resultsList, detail) {
  // hide or show the right stuff
}

// export the callbacks
export {
  connectingCallback,
  connectedCallback,
  connectingFaildeCallback,
  queryDataPreparingCallback,
  queryDataRecievingCallback,
  queryDataRecievedCallback,
  resultsDataRecievingCallback,
  resultsDataRecievedCallback,
};